//! Manually niched type replacements.

pub mod niched_option;
pub mod niching;
pub mod option_box;
pub mod option_nonzero;
